<?php

namespace Events\Event\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Events\Event\Http\Requests\EventsRequest;
use Events\Event\Interfaces\EventsRepositoryInterface;
use Events\Event\Models\Events;
use Events\Event\Forms\Events as Form;

/**
 * APIController  class for events.
 */
class EventsAPIController extends BaseController
{

    /**
     * Initialize events resource controller.
     *
     * @param type EventsRepositoryInterface $events
     *
     * @return null
     */
    public function __construct(EventsRepositoryInterface $events)
    {
        parent::__construct();
        $this->repository = $events;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Events\Event\Repositories\Criteria\EventsResourceCriteria::class);
    }

    /**
     * Display a list of events.
     *
     * @return Response
     */
    public function index(EventsRequest $request)
    {
        return $this->repository
            ->setPresenter(\Events\Event\Repositories\Presenter\EventsPresenter::class)
            ->paginate();
    }

    /**
     * Display events.
     *
     * @param Request $request
     * @param Model   $events
     *
     * @return Response
     */
    public function show(EventsRequest $request, Events $events)
    {
        return $events->setPresenter(\Events\Event\Repositories\Presenter\EventsListPresenter::class);
        ;
    }

    /**
     * Create new events.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EventsRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('event::events.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('event/events/' . $events->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/events');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the events.
     *
     * @param Request $request
     * @param Model   $events
     *
     * @return Response
     */
    public function update(EventsRequest $request, Events $events)
    {
        try {
            $data = $request->all();

            $events->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('event::events.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('event/events/' . $events->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/events/' . $events->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the events.
     *
     * @param Model   $events
     *
     * @return Response
     */
    public function destroy(EventsRequest $request, Events $events)
    {
        try {
            $events->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('event::events.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('event/events/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('event/events/' . $events->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
